@@ -6,6 +6,7 @@ from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.encoding.configurations.subtitles.dvb_subtitle.dvb_subtitle_api import DvbSubtitleApi
 from bitmovin_api_sdk.encoding.configurations.subtitles.webvtt.webvtt_api import WebvttApi
+from bitmovin_api_sdk.encoding.configurations.subtitles.imsc.imsc_api import ImscApi
 
 
 class SubtitlesApi(BaseApi):
@@ -33,3 +34,10 @@ class SubtitlesApi(BaseApi):
             base_url=base_url,
             logger=logger
         )
+
+        self.imsc = ImscApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
