@@ -9,6 +9,7 @@ from bitmovin_api_sdk.models.live_encoding import LiveEncoding
 from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
 from bitmovin_api_sdk.models.response_error import ResponseError
 from bitmovin_api_sdk.models.start_live_encoding_request import StartLiveEncodingRequest
+from bitmovin_api_sdk.encoding.encodings.live.reset_live_manifest_timeshift.reset_live_manifest_timeshift_api import ResetLiveManifestTimeshiftApi
 from bitmovin_api_sdk.encoding.encodings.live.hd.hd_api import HdApi
 from bitmovin_api_sdk.encoding.encodings.live.insertable_content.insertable_content_api import InsertableContentApi
 from bitmovin_api_sdk.encoding.encodings.live.scte35_cue.scte35_cue_api import Scte35CueApi
@@ -26,6 +27,13 @@ class LiveApi(BaseApi):
             logger=logger
         )
 
+        self.reset_live_manifest_timeshift = ResetLiveManifestTimeshiftApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
+
         self.hd = HdApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
