@@ -8,6 +8,7 @@ from bitmovin_api_sdk.encoding.infrastructure.aws.aws_api import AwsApi
 from bitmovin_api_sdk.encoding.infrastructure.static_ips.static_ips_api import StaticIpsApi
 from bitmovin_api_sdk.encoding.infrastructure.azure.azure_api import AzureApi
 from bitmovin_api_sdk.encoding.infrastructure.gce.gce_api import GceApi
+from bitmovin_api_sdk.encoding.infrastructure.akamai.akamai_api import AkamaiApi
 from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.prewarmed_encoder_pools_api import PrewarmedEncoderPoolsApi
 
 
@@ -51,6 +52,13 @@ class InfrastructureApi(BaseApi):
             logger=logger
         )
 
+        self.akamai = AkamaiApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
+
         self.prewarmed_encoder_pools = PrewarmedEncoderPoolsApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
