@@ -5,6 +5,7 @@ from __future__ import absolute_import
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.encoding.live.stream_keys.stream_keys_api import StreamKeysApi
+from bitmovin_api_sdk.encoding.live.standby_pools.standby_pools_api import StandbyPoolsApi
 
 
 class LiveApi(BaseApi):
@@ -25,3 +26,10 @@ class LiveApi(BaseApi):
             base_url=base_url,
             logger=logger
         )
+
+        self.standby_pools = StandbyPoolsApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
