@@ -44,14 +44,15 @@ from bitmovin_api_sdk.models.adaptation_set_type_response import AdaptationSetTy
 from bitmovin_api_sdk.models.adaptive_quant_mode import AdaptiveQuantMode
 from bitmovin_api_sdk.models.aes_encryption_drm import AesEncryptionDrm
 from bitmovin_api_sdk.models.aes_encryption_method import AesEncryptionMethod
+from bitmovin_api_sdk.models.akamai_account import AkamaiAccount
+from bitmovin_api_sdk.models.akamai_account_region_settings import AkamaiAccountRegionSettings
+from bitmovin_api_sdk.models.akamai_cloud_region import AkamaiCloudRegion
 from bitmovin_api_sdk.models.akamai_msl_output import AkamaiMslOutput
 from bitmovin_api_sdk.models.akamai_msl_stream_format import AkamaiMslStreamFormat
 from bitmovin_api_sdk.models.akamai_msl_version import AkamaiMslVersion
 from bitmovin_api_sdk.models.akamai_net_storage_input import AkamaiNetStorageInput
 from bitmovin_api_sdk.models.akamai_net_storage_output import AkamaiNetStorageOutput
 from bitmovin_api_sdk.models.analytics_abstract_filter import AnalyticsAbstractFilter
-from bitmovin_api_sdk.models.analytics_ads_impression_sample import AnalyticsAdsImpressionSample
-from bitmovin_api_sdk.models.analytics_ads_impressions_response import AnalyticsAdsImpressionsResponse
 from bitmovin_api_sdk.models.analytics_attribute import AnalyticsAttribute
 from bitmovin_api_sdk.models.analytics_avg_concurrent_viewers_response import AnalyticsAvgConcurrentViewersResponse
 from bitmovin_api_sdk.models.analytics_avg_dropped_frames_response import AnalyticsAvgDroppedFramesResponse
@@ -180,6 +181,7 @@ from bitmovin_api_sdk.models.burn_in_subtitle_dvb_sub import BurnInSubtitleDvbSu
 from bitmovin_api_sdk.models.burn_in_subtitle_srt import BurnInSubtitleSrt
 from bitmovin_api_sdk.models.caption_character_encoding import CaptionCharacterEncoding
 from bitmovin_api_sdk.models.cdn_output import CdnOutput
+from bitmovin_api_sdk.models.cdn_provider import CdnProvider
 from bitmovin_api_sdk.models.cdn_usage import CdnUsage
 from bitmovin_api_sdk.models.cdn_usage_statistics import CdnUsageStatistics
 from bitmovin_api_sdk.models.cea608708_subtitle_configuration import Cea608708SubtitleConfiguration
@@ -236,6 +238,7 @@ from bitmovin_api_sdk.models.dash_cmaf_representation import DashCmafRepresentat
 from bitmovin_api_sdk.models.dash_edition_compatibility import DashEditionCompatibility
 from bitmovin_api_sdk.models.dash_fmp4_drm_representation import DashFmp4DrmRepresentation
 from bitmovin_api_sdk.models.dash_fmp4_representation import DashFmp4Representation
+from bitmovin_api_sdk.models.dash_iso8601_timestamp_format import DashISO8601TimestampFormat
 from bitmovin_api_sdk.models.dash_imsc_representation import DashImscRepresentation
 from bitmovin_api_sdk.models.dash_manifest import DashManifest
 from bitmovin_api_sdk.models.dash_manifest_default import DashManifestDefault
@@ -354,6 +357,11 @@ from bitmovin_api_sdk.models.encoding_stats import EncodingStats
 from bitmovin_api_sdk.models.encoding_stream_input import EncodingStreamInput
 from bitmovin_api_sdk.models.encoding_stream_input_details import EncodingStreamInputDetails
 from bitmovin_api_sdk.models.encoding_template import EncodingTemplate
+from bitmovin_api_sdk.models.encoding_template_details import EncodingTemplateDetails
+from bitmovin_api_sdk.models.encoding_template_request import EncodingTemplateRequest
+from bitmovin_api_sdk.models.encoding_template_response import EncodingTemplateResponse
+from bitmovin_api_sdk.models.encoding_template_start_response import EncodingTemplateStartResponse
+from bitmovin_api_sdk.models.encoding_template_type import EncodingTemplateType
 from bitmovin_api_sdk.models.encoding_type import EncodingType
 from bitmovin_api_sdk.models.encryption_mode import EncryptionMode
 from bitmovin_api_sdk.models.enhanced_deinterlace_auto_enable import EnhancedDeinterlaceAutoEnable
@@ -408,9 +416,6 @@ from bitmovin_api_sdk.models.he_aac_v1_audio_configuration import HeAacV1AudioCo
 from bitmovin_api_sdk.models.he_aac_v1_signaling import HeAacV1Signaling
 from bitmovin_api_sdk.models.he_aac_v2_audio_configuration import HeAacV2AudioConfiguration
 from bitmovin_api_sdk.models.he_aac_v2_signaling import HeAacV2Signaling
-from bitmovin_api_sdk.models.history_encoding import HistoryEncoding
-from bitmovin_api_sdk.models.history_muxing import HistoryMuxing
-from bitmovin_api_sdk.models.history_stream import HistoryStream
 from bitmovin_api_sdk.models.hls_manifest import HlsManifest
 from bitmovin_api_sdk.models.hls_manifest_ad_marker_settings import HlsManifestAdMarkerSettings
 from bitmovin_api_sdk.models.hls_manifest_ad_marker_type import HlsManifestAdMarkerType
@@ -480,6 +485,18 @@ from bitmovin_api_sdk.models.live_options_entry import LiveOptionsEntry
 from bitmovin_api_sdk.models.live_options_statistics import LiveOptionsStatistics
 from bitmovin_api_sdk.models.live_options_summary import LiveOptionsSummary
 from bitmovin_api_sdk.models.live_options_type import LiveOptionsType
+from bitmovin_api_sdk.models.live_standby_pool_details import LiveStandbyPoolDetails
+from bitmovin_api_sdk.models.live_standby_pool_encoding import LiveStandbyPoolEncoding
+from bitmovin_api_sdk.models.live_standby_pool_encoding_ingest_point import LiveStandbyPoolEncodingIngestPoint
+from bitmovin_api_sdk.models.live_standby_pool_encoding_manifest import LiveStandbyPoolEncodingManifest
+from bitmovin_api_sdk.models.live_standby_pool_encoding_manifest_type import LiveStandbyPoolEncodingManifestType
+from bitmovin_api_sdk.models.live_standby_pool_encoding_status import LiveStandbyPoolEncodingStatus
+from bitmovin_api_sdk.models.live_standby_pool_event_log import LiveStandbyPoolEventLog
+from bitmovin_api_sdk.models.live_standby_pool_event_log_type import LiveStandbyPoolEventLogType
+from bitmovin_api_sdk.models.live_standby_pool_request import LiveStandbyPoolRequest
+from bitmovin_api_sdk.models.live_standby_pool_response import LiveStandbyPoolResponse
+from bitmovin_api_sdk.models.live_standby_pool_status import LiveStandbyPoolStatus
+from bitmovin_api_sdk.models.live_standby_pool_update import LiveStandbyPoolUpdate
 from bitmovin_api_sdk.models.local_input import LocalInput
 from bitmovin_api_sdk.models.local_output import LocalOutput
 from bitmovin_api_sdk.models.manifest import Manifest
@@ -576,6 +593,8 @@ from bitmovin_api_sdk.models.prime_time_drm import PrimeTimeDrm
 from bitmovin_api_sdk.models.profile_h262 import ProfileH262
 from bitmovin_api_sdk.models.profile_h264 import ProfileH264
 from bitmovin_api_sdk.models.profile_h265 import ProfileH265
+from bitmovin_api_sdk.models.program_date_time_placement import ProgramDateTimePlacement
+from bitmovin_api_sdk.models.program_date_time_placement_mode import ProgramDateTimePlacementMode
 from bitmovin_api_sdk.models.program_date_time_settings import ProgramDateTimeSettings
 from bitmovin_api_sdk.models.program_date_time_source import ProgramDateTimeSource
 from bitmovin_api_sdk.models.progressive_mov_muxing import ProgressiveMovMuxing
@@ -626,6 +645,7 @@ from bitmovin_api_sdk.models.scheduled_insertable_content import ScheduledInsert
 from bitmovin_api_sdk.models.scheduled_insertable_content_status import ScheduledInsertableContentStatus
 from bitmovin_api_sdk.models.scheduling import Scheduling
 from bitmovin_api_sdk.models.scte35_cue import Scte35Cue
+from bitmovin_api_sdk.models.scte35_trigger import Scte35Trigger
 from bitmovin_api_sdk.models.segmented_raw_muxing import SegmentedRawMuxing
 from bitmovin_api_sdk.models.segments_media_info import SegmentsMediaInfo
 from bitmovin_api_sdk.models.sftp_input import SftpInput
@@ -696,6 +716,7 @@ from bitmovin_api_sdk.models.srt_statistic_recv import SrtStatisticRecv
 from bitmovin_api_sdk.models.srt_statistic_send import SrtStatisticSend
 from bitmovin_api_sdk.models.srt_statistic_window import SrtStatisticWindow
 from bitmovin_api_sdk.models.srt_statistics import SrtStatistics
+from bitmovin_api_sdk.models.srt_to_cea608708_caption import SrtToCea608708Caption
 from bitmovin_api_sdk.models.standard_media_info import StandardMediaInfo
 from bitmovin_api_sdk.models.start_encoding_request import StartEncodingRequest
 from bitmovin_api_sdk.models.start_live_channel_encoding_request import StartLiveChannelEncodingRequest
@@ -772,7 +793,6 @@ from bitmovin_api_sdk.models.thumbnail import Thumbnail
 from bitmovin_api_sdk.models.thumbnail_aspect_mode import ThumbnailAspectMode
 from bitmovin_api_sdk.models.thumbnail_unit import ThumbnailUnit
 from bitmovin_api_sdk.models.time_based_trimming_input_stream import TimeBasedTrimmingInputStream
-from bitmovin_api_sdk.models.time_code import TimeCode
 from bitmovin_api_sdk.models.time_span import TimeSpan
 from bitmovin_api_sdk.models.timecode_track_trimming_input_stream import TimecodeTrackTrimmingInputStream
 from bitmovin_api_sdk.models.transfer_retry import TransferRetry
