@@ -28,3 +28,5 @@ class AzureCloudRegion(Enum):
     US_WEST = "US_WEST"
     US_WEST2 = "US_WEST2"
     US_SOUTH_CENTRAL = "US_SOUTH_CENTRAL"
+    US_NORTH_CENTRAL = "US_NORTH_CENTRAL"
+    UK_SOUTH = "UK_SOUTH"
